#!/usr/bin/env python

import os
import sys
from netCDF4 import Dataset
import numpy as np


def get_arguments():
    from argparse import ArgumentParser

    argp = ArgumentParser()

    argp.add_argument('nc_out', help='Output NetCDF file')
    argp.add_argument('nc_list', help='List of netCDF files to sum')

    args = argp.parse_args()

    nc_out = args.nc_out
    nc_list = args.nc_list.split()

    return nc_out, nc_list


def copy_first_emis_file(nc_out, base_emis_file):
    from shutil import copyfile

    if os.path.isfile(nc_out):
        os.remove(nc_out)

    copyfile(base_emis_file, nc_out)
    print('Coping {0} file'.format(base_emis_file))

    return True


def add_emis(nc_out, nc_list):
    nc_out = Dataset(nc_out, mode='r+')

    for nc_file in nc_list:
        print('Adding emissions from {0}'.format(nc_file))
        nc = Dataset(nc_file, mode='r')
        out_variables = nc_out.variables
        in_variables = list(nc.variables.keys())
        for var in in_variables:
            print('\t{0}'.format(var))
            sys.stdout.flush()
            if var not in ['time', 'lat', 'lon', 'lat_bnds', 'lon_bnds', 'rlat', 'rlon', 'lev', 'rotated_pole', 'crs',
                           'cell_area', 'TFLAG', 'Times']:
                if var not in out_variables:
                    var_new = nc_out.createVariable(var, nc.variables[var].datatype, nc.variables[var].dimensions)
                    for ncattr in nc.variables[var].ncattrs():
                        var_new.setncattr(ncattr, str(nc.variables[var].getncattr(ncattr)))
                        var_new[:] = nc[var][:]
                else:
                    try:
                        var_aux = nc[var][:].data
                        var_aux[nc[var][:].mask] = 0
                    except AttributeError:
                        var_aux = nc[var][:]
                    nc_out[var][:] += var_aux

        nc.close()

    nc_out.close()

def run():
    output_netcdf, netcdf_file_list = get_arguments()
    copy_first_emis_file(output_netcdf, netcdf_file_list[0])
    add_emis(output_netcdf, netcdf_file_list[1:])


if __name__ == '__main__':
    run()




